#
# spec file for package cargo
#
# Copyright (c) 2017 SUSE LINUX GmbH, Nuernberg, Germany.
# Copyright (c) 2016 Michal Vyskocil, michal.vyskocil@opensuse.org
# Copyright (c) 2016 Kristoffer Gronlund, kgronlund@suse.com
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%global prev_version 0.13.0
%global prev_rustc 1.13.0

Name:           cargo
Version:        0.15.0
Release:        2.3
Summary:        The Rust package manager
License:        MIT or Apache-2.0
Group:          Development/Languages/Other
Url:            https://github.com/rust-lang/cargo

# See README.packager for instructions on generating
# the source archives
Source0:        %{name}-%{version}.tar.gz
Source1:        vendor.tar.xz
Source2:        README.packager
# PATCH-FIX-UPSTREAM -- https://github.com/rust-lang/cargo/pull/3554
Patch0:         reproducible.patch

BuildRequires:  cargo >= %{prev_version}
BuildRequires:  cmake
BuildRequires:  curl
BuildRequires:  git
BuildRequires:  libcurl-devel
BuildRequires:  libopenssl-devel
BuildRequires:  libssh-devel
BuildRequires:  rustc-stable >= %{prev_rustc}
BuildRequires:  zlib-devel

Conflicts:      cargo-bootstrap

BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Cargo downloads your Rust project’s dependencies and compiles your project.

%prep
%setup -q
%setup -q -D -T -a 1
%patch0 -p1
mkdir cargo-home
cat >cargo-home/config <<EOF
[source.crates-io]
registry = 'https://github.com/rust-lang/crates.io-index'
replace-with = 'vendored-sources'
[source.vendored-sources]
directory = './vendor'
EOF

%build
export CARGO_HOME=`pwd`/cargo-home/
./configure
cargo build --release %{?_smp_mflags}

%install
mkdir build
export CARGO_HOME=`pwd`/cargo-home/
cargo install --root=build
mkdir -p %{buildroot}%{_bindir}
install -Dm0755 build/bin/cargo %{buildroot}%{_bindir}/cargo
mkdir -p %{buildroot}%{_mandir}/man1
install -Dm0644 src/etc/man/cargo*.1 %{buildroot}%{_mandir}/man1/
install -Dm0644 src/etc/cargo.bashcomp.sh %{buildroot}%{_sysconfdir}/bash_completion.d/cargo.sh

%files
%defattr(-,root,root)
%doc LICENSE-APACHE LICENSE-MIT README.md
%{_bindir}/cargo
%doc %{_mandir}/man1/*
%config %{_sysconfdir}/bash_completion.d/cargo.sh

%changelog
* Tue Jan 31 2017 luke.nukem.jones@gmail.com
- Update to 0.15.0
* Tue Jan 17 2017 bwiedemann@suse.com
- Add reproducible.patch to allow for reproducible builds
* Thu Nov  3 2016 matwey.kornilov@gmail.com
- Update to 0.13.0
* Wed Aug 10 2016 kgronlund@suse.com
- Update to 0.11.0
  * Fix compilation using rustc 1.10
  * Implement the `panic` profile option
  * Don't throw away errors with `-p` arguments
* Sun Jul  3 2016 kgronlund@suse.com
- Revised packaging to rely on cargo-vendor
* Wed Jun 29 2016 kgronlund@suse.com
- Update to 0.10.0
- Revised packaging to rely on cargo-bootstrap project when building
* Sun Apr 17 2016 mvyskocil@opensuse.org
- Update to 0.9.0
* Wed Feb 10 2016 mvyskocil@opensuse.org
- Adapted version (per review request)
* Thu Jan 28 2016 mvyskocil@opensuse.org
- Initial packaging of cargo for openSUSE
